@@ -1,6 +1,7 @@
 from os       import close
 from sys      import getrefcount
 from tempfile import mkstemp
+from tempfile import mkdtemp
 from operator import mul
 
 from numpy import empty   as numpy_empty
@@ -428,11 +429,13 @@ set with the `cf.TEMPDIR` function.
         # Use mkstemp because we want to be responsible for deleting
         # the temporary file when done with it.
         # ------------------------------------------------------------
+        _partition_dir = mkdtemp(prefix='cf_array_', dir=CONSTANTS['TEMPDIR'])
         fd, _partition_file = mkstemp(prefix='cf_array_', suffix='.npy', 
-                                      dir=CONSTANTS['TEMPDIR'])
+                                      dir=_partition_dir)
         close(fd)
 
         # The name of the temporary file storing the array
+        self._partition_dir = _partition_dir
         self._partition_file = _partition_file
 
         # Numpy data type of the array
