@@ -1,5 +1,6 @@
 import resource
 import copy
+import ctypes
 import cPickle
 import netCDF4
 import psutil
@@ -2536,6 +2537,7 @@ def environment(display=True):
 Platform: Linux-4.4.0-53-generic-x86_64-with-debian-stretch-sid
 HDF5 library: 1.8.17
 netcdf library: 4.4.1
+udunits2: /home/space/anaconda2/lib/libudunits2.so.0
 python: 2.7.13 /home/space/anaconda2/bin/python
 netCDF4: 1.2.4 /home/space/anaconda2/lib/python2.7/site-packages/netCDF4/__init__.pyc
 numpy: 1.11.3 /home/space/anaconda2/lib/python2.7/site-packages/numpy/__init__.pyc
@@ -2550,6 +2552,7 @@ cf: 2.0.2 /home/space/cf-python/cf/__init__.pyc
     out.append('Platform: ' + str(platform()))
     out.append('HDF5 library: ' + str(netCDF4. __hdf5libversion__))
     out.append('netcdf library: ' + str(netCDF4.__netcdf4libversion__))
+    out.append('udunits2: ' + str(ctypes.util.find_library('udunits2')))
     out.append('python: ' + str(python_version() + ' ' + str(sys_executable)))
     out.append('netCDF4: ' + str(netCDF4.__version__) + ' ' + str(os_path_abspath(netCDF4.__file__)))
     out.append('numpy: ' + str(numpy__version__) + ' ' + str(os_path_abspath(numpy__file__)))
