@@ -23,13 +23,19 @@ from .data.data import Data
 class Query(object):
     '''Store a query operation.
 
-The query operation is an operator with a right hand side operand. For
-example, an operator could be "strictly less than" and a right hand
-side operand could 3.
+A query is an inquiry into any object that ascertains if, and possibly
+where, the object satisfies the inquiry. For example the query "is
+this strictly less than 3?" may be applied to the number 2.5, giving a
+result of `True`. The same query may be applied to the number 3 to
+give a result of `False`.
 
-Such a query (such as "is strictly less than 3?") may be evaluated for
-an arbitrary left hand side operand, *x* (such as "is *x* strictly
-less than 3?").
+The query operation is an operator with a right hand side operand. For
+example, an operator could be "strictly less than (<)" and a right
+hand side operand could 3.
+
+Such a query (such as "is this strictly less than 3?") may be
+evaluated for an arbitrary left hand side operand, *x* (i.e. "is *x*
+strictly less than 3?").
 
 The result of the query is dependent on the object type of left hand
 side operand, *x*. For example, if *x* is an integer then evaluating
@@ -37,8 +43,10 @@ side operand, *x*. For example, if *x* is an integer then evaluating
 a `numpy` array then "is *x* strictly less than 3?" will likely
 produce a numpy array of booleans.
 
-The query is evaluated with its `evaluate` method or equivalently with
-the ``==`` operator:
+The query is evaluated for an object with its `evaluate` method or
+equivalently with the ``==`` operator. For example to test the query
+"is this strictly less than 3?" against the number 2, any of the
+following three methods may be used:
 
 >>> q = cf.Query('lt', 3)
 >>> q.evaluate(2)
@@ -47,8 +55,6 @@ True
 True
 >>> q == 2
 True
->>> 4 == q
-False
 
 The inverse of the query may be evaluated with the ``!=`` operator:
 
@@ -627,9 +633,7 @@ Return a string containing a full description of the instance.
     #--- End: def
 
     def evaluate(self, x):
-        '''
-
-Evaluate the query operation for a given left hand side operand.
+        '''Evaluate the query operation for a given left hand side operand.
 
 Note that for the query object ``q`` and any object, ``x``, ``x==q``
 is equivalent to ``q.evaluate(x)`` and ``x!=q`` is equivalent to
@@ -659,7 +663,7 @@ array([0, 1, 2, 3])
 >>> q.evaluate(array)
 array([False,  True,  True, False], dtype=bool)
 
-'''
+        '''
         return self._evaluate(x, ())
     #--- End: def
 
@@ -2022,9 +2026,11 @@ attr='upper_bounds')``.
 #--- End: def
 
 def jja():
-    '''Return a `cf.Query` object for season June, July, August.
+    '''Return a `cf.Query` object for month of June, July or August.
 
-``cf.jja()`` is equivalent to ``cf.month(cf.wi(6, 8))``.
+Note that any date-time that lies in these months will satisfy
+the query, i.e. ``cf.jja()`` is equivalent to ``cf.month(cf.wi(6,
+8))``.
 
 .. versionadded:: 1.0
 
@@ -2048,10 +2054,12 @@ def jja():
 #--- End: def
 
 def son():
-    '''Return a `cf.Query` object for season September, October,
+    '''Return a `cf.Query` object for month of September, October or
 November.
 
-``cf.son()`` is equivalent to ``cf.month(cf.wi(9, 11))``.
+Note that any date-time that lies in these months will satisfy
+the query, i.e. ``cf.son()`` is equivalent to ``cf.month(cf.wi(9,
+11))``.
 
 .. versionadded:: 1.0
 
@@ -2075,9 +2083,12 @@ November.
 #--- End: def
 
 def djf():
-    '''Return a `cf.Query` object for season December, January, February.
+    '''Return a `cf.Query` object for the month of December, January or
+February.
 
-``cf.djf()`` is equivalent to ``cf.month(cf.ge(12) | cf.le(2))``.
+Note that any date-time that lies in these months will satisfy
+the query, i.e. ``cf.djf()`` is equivalent to ``cf.month(cf.ge(12) |
+cf.le(2))``.
 
 .. versionadded:: 1.0
 
@@ -2102,9 +2113,10 @@ def djf():
 #--- End: def
 
 def mam():
-    '''Return a `cf.Query` object for the season March, April, May.
+    '''Return a `cf.Query` object for the month of March, April or May.
 
-``cf.mam()`` is equivalent to ``cf.month(cf.wi(3, 5))``.
+Note that any date-time that lies in these months will satisfy
+the query, i.e. ``cf.mam()`` is equivalent to ``cf.month(cf.wi(3, 5))``.
 
 .. versionadded:: 1.0
 
@@ -2129,7 +2141,11 @@ def mam():
 #--- End: def
 
 def seasons(n=4, start=12):
-    '''Return a list `cf.Query` objects for all seasons in a year.
+    '''Return a list `cf.Query` objects corresponding to seasons in a
+year.
+
+Note that any date-time that lies within a particular season will
+satisfy that query.
 
 .. versionadded:: 1.0
 
