@@ -1,4 +1,14 @@
 from .netcdf.write import write as netcdf_write
+from os.path       import abspath
+
+from . import mpi_on
+if mpi_on:
+    from . import mpi_comm
+    from . import mpi_size
+    from . import mpi_rank
+#--- End: if
+
+from .functions import FREE_MEMORY_FACTOR
 
 def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
@@ -252,10 +262,7 @@ which have equal values across all input fields.
         available at
         https://www.hdfgroup.org/HDF5/doc/H5.user/Chunking.html and
         http://www.unidata.ucar.edu/software/netcdf/workshops/2011/nc4chunking.
-        Basically, you want the chunks for each dimension to match as
-        closely as possible the size and shape of the data block that
-        users will read from the file.
-
+        
     unlimited: sequence of `str`, optional
         Create unlimited dimensions (dimensions that can be appended
         to). A dimension is identified by either a standard name; one
@@ -283,7 +290,31 @@ which have equal values across all input fields.
  <CF Field: v_compnt_of_wind(19, 29, 24)>,
  <CF Field: potential_temperature(19, 30, 24)>]
 
-    '''      
+    '''
+
+    if mpi_on:
+        path = abspath(filename)
+        paths = mpi_comm.allgather(path)
+        unique_paths = set(paths)
+        n_unique_paths = len(unique_paths)
+        if n_unique_paths == 1:
+            write_only_on_pe0 = True
+        elif n_unique_paths == mpi_size:
+            write_only_on_pe0 = False
+        else:
+            raise RuntimeError('write expects either 1 unique filename or as many as there are PEs')
+        #--- End: if
+
+        if write_only_on_pe0:
+            if mpi_rank == 0:
+                old_free_memory_factor = FREE_MEMORY_FACTOR(1)
+            else:
+                mpi_comm.Barrier()
+                return
+            #--- End: if
+        #--- End: if
+    #--- End: if
+
     if fields:
         netcdf_write(fields, filename, fmt=fmt, overwrite=overwrite,
                      verbose=verbose, cfa_options=cfa_options,
@@ -296,4 +327,10 @@ which have equal values across all input fields.
                      variable_attributes=variable_attributes,
                      HDF_chunks=HDF_chunksizes, unlimited=unlimited,
                      _debug=_debug)
+    #--- End: if
+
+    if mpi_on and write_only_on_pe0:
+        FREE_MEMORY_FACTOR(old_free_memory_factor)
+        mpi_comm.Barrier()
+    #--- End: if
 #--- End: def
